@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-from ..html import *
+from ..h import *
 from ..messages import *
 
 def requiredIDs(doc):
