@@ -98,7 +98,7 @@ def addMdnPanels(doc):
             '''  # noqa
 
 def createAnno(className, mdnButton, featureDivs):
-    return E.aside({"class": className}, mdnButton, featureDivs)
+    return E.div({"class": className}, mdnButton, featureDivs)
 
 def panelsFromData(doc, data):
     mdnBaseUrl = "https://developer.mozilla.org/en-US/docs/Web/"
@@ -131,6 +131,8 @@ def panelsFromData(doc, data):
 
     panels = False
     for elementId, features in data.items():
+        isAnnoForHeadingContent = False
+        isAnnoForListItemOrTableContent = False
         lessThanTwoEngines = 0
         onlyTwoEngines = 0
         allEngines = 0
@@ -158,8 +160,6 @@ def panelsFromData(doc, data):
                     if ancestor.tag in ['pre', 'xmp', 'p']:
                         break
         for feature in features:
-            isAnnoForHeadingContent = False
-            isAnnoForListItemOrTableContent = False
             if "engines" in feature:
                 engines = len(feature["engines"])
                 if engines < 2:
